@@ -282,6 +282,7 @@ class Transform(BASE, ModelBase):
     max_update_retries = Column(Integer(), default=0)
     new_poll_period = Column(Interval(), default=datetime.timedelta(seconds=1))
     update_poll_period = Column(Interval(), default=datetime.timedelta(seconds=10))
+    name = Column(String(NAME_LENGTH))
     errors = Column(JSONString(1024))
     _transform_metadata = Column('transform_metadata', JSON())
     _running_metadata = Column('running_metadata', JSON())
@@ -469,6 +470,8 @@ class Collection(BASE, ModelBase):
     new_files = Column(Integer())
     processed_files = Column(Integer())
     processing_files = Column(Integer())
+    failed_files = Column(Integer())
+    missing_files = Column(Integer())
     processing_id = Column(Integer())
     retries = Column(Integer(), default=0)
     created_at = Column("created_at", DateTime, default=datetime.datetime.utcnow)
