@@ -36,13 +36,15 @@ from idds.workflowv2.workflow import Workflow
 # from idds.atlas.workflowv2.atlasstageinwork import ATLASStageinWork
 from idds.doma.workflowv2.domapandawork import DomaPanDAWork
 
+# task_cloud = 'LSST'
+task_cloud = 'US'
 
 task_queue = 'DOMA_LSST_GOOGLE_TEST'
 # task_queue = 'DOMA_LSST_GOOGLE_MERGE'
 # task_queue = 'SLAC_TEST'
 # task_queue = 'DOMA_LSST_SLAC_TEST'
 task_queue = 'SLAC_Rubin'
-task_queue = 'CC-IN2P3_TEST'
+# task_queue = 'CC-IN2P3_TEST'
 
 
 def randStr(chars=string.ascii_lowercase + string.digits, N=10):
@@ -137,7 +139,7 @@ def setup_workflow():
                                     "token": "local",
                                     "type": "template",
                                     "value": "log.tgz"},
-                          task_cloud='LSST')
+                          task_cloud=task_cloud)
     work2 = DomaPanDAWork(executable='echo',
                           primary_input_collection={'scope': 'pseudo_dataset', 'name': 'pseudo_input_collection#2'},
                           output_collections=[{'scope': 'pseudo_dataset', 'name': 'pseudo_output_collection#2'}],
@@ -151,7 +153,7 @@ def setup_workflow():
                                     "token": "local",
                                     "type": "template",
                                     "value": "log.tgz"},
-                          task_cloud='LSST')
+                          task_cloud=task_cloud)
     work3 = DomaPanDAWork(executable='echo',
                           primary_input_collection={'scope': 'pseudo_dataset', 'name': 'pseudo_input_collection#3'},
                           output_collections=[{'scope': 'pseudo_dataset', 'name': 'pseudo_output_collection#3'}],
@@ -165,7 +167,7 @@ def setup_workflow():
                                     "token": "local",
                                     "type": "template",
                                     "value": "log.tgz"},
-                          task_cloud='LSST')
+                          task_cloud=task_cloud)
 
     pending_time = 12
     # pending_time = None
